@@ -1,6 +1,6 @@
-/* tigers.h       2023-10-06 */
+/* tigers.h       2024-01-26 */
 
-/* Copyright 2023 Emmanuel Paradis */
+/* Copyright 2023-2024 Emmanuel Paradis */
 
 /* This file is part of the R-package `tigers'. */
 /* See the file ../DESCRIPTION for licensing issues. */
@@ -16,7 +16,7 @@ void test_Hormann_Floater(double *xy, double *Pxy, double *bary_coords, int *pat
 SEXP triangulate_Call(SEXP XY, SEXP METHOD);
 SEXP haveOverlapTwoPolygons(SEXP P, SEXP Q);
 SEXP redundant_vertices(SEXP POLYGON, SEXP TOL, SEXP CHECK_ONLY);
-SEXP area_Call(SEXP XY, SEXP METHOD);
+SEXP area_Call(SEXP XY);
 SEXP rev_Call(SEXP x, SEXP copy);
 SEXP rev_2cols_Call(SEXP x, SEXP copy);
 SEXP RMA_Call(SEXP X, SEXP Y);
